@@ -13,7 +13,7 @@ import requests
 
 from .bash import get_mac_addresses
 from .logify import Logify
-from .exceptions import AWSMetaDataError
+from .exceptions import AWSMetaDataError, CommandError
 
 
 __author__ = 'Joe Yennaco'
@@ -25,6 +25,8 @@ mod_logger = Logify.get_name() + '.aws_metadata'
 # AWS Meta Data Service URL
 metadata_url = 'http://169.254.169.254/latest/meta-data/'
 
+character_encoding = 'utf-8'
+
 
 def is_aws():
     """Determines if this system is on AWS
@@ -41,7 +43,7 @@ def is_aws():
 
     while True:
         if attempt_num > max_num_tries:
-            log.info('Unable to query the AWS meta data URL, this system appears to be not running on AWS\n{e}')
+            log.info('Unable to query the AWS meta data URL, this system appears to be not running on AWS')
             return False
 
         # Query the AWS meta data URL
@@ -92,6 +94,8 @@ def get_instance_id():
         log.error(msg)
         return
     instance_id = response.content
+    if isinstance(instance_id, bytes):
+        instance_id = instance_id.decode(character_encoding)
     return instance_id
 
 
@@ -100,12 +104,12 @@ def get_vpc_id_from_mac_address():
 
     :return: String instance ID or None
     """
-    log = logging.getLogger(mod_logger + '.get_vpc_id')
+    log = logging.getLogger(mod_logger + '.get_vpc_id_from_mac_address')
 
     # Exit if not running on AWS
-    if not is_aws():
-        log.info('This machine is not running in AWS, exiting...')
-        return
+    # if not is_aws():
+    #     log.info('This machine is not running in AWS, exiting...')
+    #     return
 
     # Get the primary interface MAC address to query the meta data service
     log.debug('Attempting to determine the primary interface MAC address...')
@@ -131,6 +135,8 @@ def get_vpc_id_from_mac_address():
         log.error(msg)
         return
     vpc_id = response.content
+    if isinstance(vpc_id, bytes):
+        vpc_id = vpc_id.decode(character_encoding)
     return vpc_id
 
 
@@ -170,6 +176,8 @@ def get_owner_id_from_mac_address():
         log.error(msg)
         return
     owner_id = response.content
+    if isinstance(owner_id, bytes):
+        owner_id = owner_id.decode(character_encoding)
     return owner_id
 
 
@@ -200,6 +208,8 @@ def get_availability_zone():
         log.error(msg)
         return
     availability_zone = response.content
+    if isinstance(availability_zone, bytes):
+        availability_zone = availability_zone.decode(character_encoding)
     return availability_zone
 
 
@@ -231,8 +241,12 @@ def get_primary_mac_address():
     :raises: AWSMetaDataError
     """
     log = logging.getLogger(mod_logger + '.get_primary_mac_address')
-    mac_addresses = get_mac_addresses()
+    try:
+        mac_addresses = get_mac_addresses()
+    except CommandError as exc:
+        msg = 'Problem getting mac addresses on this host'
+        raise AWSMetaDataError(msg) from exc
     if 'eth0' not in mac_addresses.keys():
-        msg = 'Problem getting the mac address for eth0'
+        msg = 'Problem getting the mac address for eth0 from list: {d}'.format(d=str(mac_addresses))
         raise AWSMetaDataError(msg)
     return mac_addresses['eth0']
